@@ -20,7 +20,7 @@ class Config(object):
         self.source = None
         if BASE_PATH.exists():
             for file in BASE_PATH.glob("*"):
-                if file.startswith('.'):
+                if file.name.startswith('.'):
                     continue
                 for section, config in self.parse_file(file):
                     self.sources[section] = config
